@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 10098 2017-07-17 07:39:01Z David $
+# $Id: __init__.py 10102 2017-07-17 09:34:46Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-07-17 15:39:01 +0800 (Mon, 17 Jul 2017) $
-# $Revision: 10098 $
+# $Date: 2017-07-17 17:34:46 +0800 (Mon, 17 Jul 2017) $
+# $Revision: 10102 $
 
 import os
 import sys
@@ -165,4 +165,21 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
 
     update(settingsDict, socailAuthSettingsDefaults)
     #=========================================================================
-    
\ No newline at end of file
+    # default login related value settings.
+    # TODO: There are lots of default values yet to set, it's better to set them
+    # all. See 
+    # https://docs.djangoproject.com/en/1.11/ref/settings/#login-redirect-url
+    # http://django-user-accounts.readthedocs.io/
+    # en/latest/settings.html#settings 
+    # http://python-social-auth-docs.readthedocs.io/
+    # en/latest/configuration/settings.html#urls-options
+    loginSettingsDefaults = {
+        'LOGIN_URL': '/accounts/login/',
+        'LOGIN_REDIRECT_URL': '/accounts/profile/',
+        'SOCIAL_AUTH_LOGIN_URL': '/accounts/login/',
+        'SOCIAL_AUTH_LOGIN_REDIRECT_URL': '/accounts/profile/',
+        'ACCOUNT_LOGIN_URL': '/accounts/login/',
+        'ACCOUNT_LOGIN_REDIRECT_URL': '/accounts/profile/',
+    }
+
+    update(settingsDict, loginSettingsDefaults)
