@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9927 2017-04-29 14:17:02Z David $
+# $Id: __init__.py 9947 2017-05-04 10:37:30Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-04-29 22:17:02 +0800 (Sat, 29 Apr 2017) $
-# $Revision: 9927 $
+# $Date: 2017-05-04 18:37:30 +0800 (Thu, 04 May 2017) $
+# $Revision: 9947 $
 
 import os
 import sys
@@ -73,10 +73,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     # Email.
     emailDefaults = {
         'ACCOUNT_EMAIL_CONFIRMATION_REQUIRED' : True,
-        'EMAIL_BACKEND' : 'django.core.mail.backends.smtp.EmailBackend',
     }
-    
-    warnWithout('EMAIL_BACKEND', settingsDict, emailDefaults)
 
     update(settingsDict, emailDefaults)
     settingsDict['OSCAR_FROM_EMAIL'] = settingsDict['DEFAULT_FROM_EMAIL']
